@@ -531,6 +531,22 @@ eel_preferences_get_string_list (const char *name)
 	return result;
 }
 
+gboolean
+eel_preferences_key_is_writable (const char *name)
+{
+	gboolean result;
+	char *key;
+	
+	g_return_val_if_fail (name != NULL, 0);
+	g_return_val_if_fail (preferences_is_initialized (), 0);
+
+	key = preferences_key_make (name);
+	result = eel_gconf_key_is_writable (key);
+	g_free (key);
+
+	return result;
+}
+
 /**
  * preferences_callback_entry_invoke_function
  *
